@@ -425,10 +425,6 @@ module StateMachines
         def matching_ancestors
           [::ActiveRecord::Base]
         end
-
-        def locale_path
-          "#{File.dirname(__FILE__)}/active_record/locale.rb"
-        end
       end
 
       protected
@@ -458,9 +454,11 @@ module StateMachines
       def define_state_initializer
         if ::ActiveRecord.gem_version >= Gem::Version.new('5.0.0.alpha')
           define_helper :instance, <<-end_eval, __FILE__, __LINE__ + 1
-            def initialize(attributes = nil)
+            def initialize(attributes = nil, *)
               super(attributes) do |*args|
-                self.class.state_machines.initialize_states(self, {}, attributes || {})
+                scoped_attributes = (attributes || {}).merge(self.class.scope_attributes)
+
+                self.class.state_machines.initialize_states(self, {}, scoped_attributes)
                 yield(*args) if block_given?
               end
             end
@@ -468,8 +466,10 @@ module StateMachines
         elsif ::ActiveRecord.gem_version >= Gem::Version.new('4.2')
           define_helper :instance, <<-end_eval, __FILE__, __LINE__ + 1
             def initialize(attributes = nil, options = {})
+              scoped_attributes = (attributes || {}).merge(self.class.scope_attributes)
+
               super(attributes, options) do |*args|
-                self.class.state_machines.initialize_states(self, {}, attributes || {})
+                self.class.state_machines.initialize_states(self, {}, scoped_attributes)
                 yield(*args) if block_given?
               end
             end
@@ -492,8 +492,10 @@ module StateMachines
           # Initializes dynamic states
           define_helper :instance, <<-end_eval, __FILE__, __LINE__ + 1
             def initialize(attributes = nil, options = {})
+              scoped_attributes = (attributes || {}).merge(self.class.scope_attributes)
+
               super(attributes, options) do |*args|
-                self.class.state_machines.initialize_states(self, {}, attributes || {})
+                self.class.state_machines.initialize_states(self, {}, scoped_attributes)
                 yield(*args) if block_given?
               end
             end
